@@ -1,6 +1,6 @@
 #' Calculate an E-value
 #'
-#' @param effect Numeric positive value. Observed exposure - outcome effect
+#' @param effect_observed Numeric positive value. Observed exposure - outcome effect
 #'    (assumed to be the exponentiated coefficient, so a relative risk, odds
 #'    ratio, or hazard ratio). This can be the point estimate, lower confidence
 #'    bound, or upper confidence bound.
@@ -11,9 +11,9 @@
 #' @examples
 #' e_value(0.9)
 #' e_value(1.3)
-e_value <- function(effect) {
-  if (effect <= 1) {
-    effect <- 1 / effect
+e_value <- function(effect_observed) {
+  if (effect_observed <= 1) {
+    effect_observed <- 1 / effect_observed
   }
-  effect + sqrt(effect * (effect - 1))
+  effect_observed + sqrt(effect_observed * (effect_observed - 1))
 }
